function csfMRI_runDesign(subID, nRun, test)

% Determine if we are in testing mode or not
	
	if (nargin < 1)
		subID = input('Please enter subject ID in single quotes: ');
        nRun  = input('Please enter run number (without quotes): ');
        test  = 0;
	elseif (nargin == 1)
        nRun  = input('Please enter run number (without quotes): ');
        test  = 0;
	elseif (nargin == 2)
		test  = 0;
	end


% Load design and stimulus IDs, get path information

    switch nRun
        
        case 1
            
            [events, onsets, durations, stimuli] = csfMRI_setDesign;
            
        otherwise
            
            load(['./' subid '/events.mat']);
            load(['./' subid '/onsets.mat']);
            load(['./' subid '/durations.mat']);
            load(['./' subid '/stimuli.mat']);
            
    end
    
    
% Initial setup
	
	% How many events are we presenting this run?
		
		nEvent = length(events(:,nRun));
        
    % Open serial device if we are in scanner mode
    
        if (test == 0)
            serialOne = serial('COM1', 'BaudRate', 9600, 'DataBits', 8);
            warning('off','MATLAB:serial:fread:unsuccessfulRead');
            fopen(serialOne);
        end
	
	
% Initialize the storage array to save time during experiment execution

		data.subjectID = subID;
		data.time      = datestr(now);
		data.responses = [];

		
% Open Screen and determine window parameters.
	
	% Find out what number screen to display on.  If you only have one 
    % display, this will use the current display; if there are two 
    % displays, the second one will be used.
		displayScreen = max(Screen('Screens'));
		
	% Make it so fewer diagnostic statements get put on the command line 
    % when running
		Screen('Preference', 'Verbosity', 1);
			
	% Open up a new Screen session. This will take up the whole window and 
    % have a black background. The screenPointer is a reference to the 
    % Screen session.  The screenRect is the size of the Screen session.
		[screenPointer, screenRect] = Screen('OpenWindow', displayScreen, [0 0 0]);
			
    % Wait a couple seconds
		WaitSecs(2);

	% Calculate the center point of the screen
		[screenWidth, screenHeight] = Screen('WindowSize', screenPointer);
		%center(1)                   = screenWidth/2;
		%center(2)                   = screenHeight/2;
		
	% Hide the cursor
		HideCursor
		
	% Set the default font for the Screen session
		Screen('TextFont', screenPointer, 'Helvetica');

% -------------------------------------------------------------------------		
		
	% Preliminary setup and hold for first trigger
    
        % Construct a large rect for the fixation
            %maxRect = [0 0 0 0];
			%fixRect = Screen('TextBounds', screenPointer, char(stimuli.actual{1}));
			%if (fixRect(3) > maxRect(3)), maxRect = fixRect; end
							
			
		% Display the text 'Ready'
            Screen('TextSize', screenPointer, 96);
			textRect   = Screen('TextBounds', screenPointer, 'Ready');
        	centerRect = CenterRect(textRect, screenRect); 			
			Screen('DrawText', screenPointer, 'Ready', centerRect(1), centerRect(2), 255);
			Screen('Flip', screenPointer); 								
			
			disp(' '); disp('/// Ready - Waiting for first trigger ///');
            
            if (test == 1)
                
				WaitSecs(2);
                triggerTime = GetSecs;
                
            else
                
				triggerTime = csfMRI_getTrigger(serialOne, screenPointer);
            
            end

			disp(' '); disp('Trigger detected, beginnging stimulus presentation'); disp(' ');
            
            % Normalize onsets to trigger time
            
                trueOnset = onsets(:,nRun) + (triggerTime - GetSecs);
		
			fprintf('           ');    
    
            
    % Present the stimuli
    
        %txtCounter = 1;
    
        for iEvent = 1:nEvent
            
            % Display what trial we are on
            
				fprintf('\b\b\b\b\b\b\b\b\b\b\b\b\b\b    Trial: %3.0f', iEvent);
                
            % Determine trial time and trial type
            
                start = GetSecs;
                trial = events(iEvent, nRun);
                
                
            % Prepare offscreen buffer depending on trial type
            
                switch trial
                
                    case {0, -1, -2, -3}
                        
                        Screen('TextSize', screenPointer, 96);
                        DrawFormattedText(screenPointer, char(stimuli.actual{iEvent, nRun}), 'center', 'center', [255 255 255]);
                        
                    case {1, 2}
                        
                        imageDisplay = Screen('MakeTexture', screenPointer, stimuli.actual{iEvent, nRun});
                        imageSize    = size(stimuli.actual{iEvent, nRun});
                        pos          = [(screenWidth-imageSize(2))*.5, (screenHeight-imageSize(1))*.5, (screenWidth+imageSize(2))*.5, (screenHeight+imageSize(1))*.5];
                        Screen(screenPointer, 'FillRect', 0);
                        Screen('DrawTexture', screenPointer, imageDisplay, [], pos);
                        
                        %Screen('TextSize', screenPointer, 24);
                        %DrawFormattedText(screenPointer, char(stimuli.txt{txtCounter, nRun}), 'center', screenHeight*.7, [255 255 255]);
                        %txtCounter   = txtCounter + 1;

                    otherwise
                
                        imageDisplay = Screen('MakeTexture', screenPointer, stimuli.actual{iEvent, nRun});
                        imageSize    = size(stimuli.actual{iEvent, nRun});
                        pos          = [(screenWidth-imageSize(2))*.5, (screenHeight-imageSize(1))*.5, (screenWidth+imageSize(2))*.5, (screenHeight+imageSize(1))*.5];
                        Screen(screenPointer, 'FillRect', 0);
                        Screen('DrawTexture', screenPointer, imageDisplay, [], pos);
                
                end
            
            % Present stimulus and wait for response until trial ends
            
                Screen('Flip', screenPointer);
                
                switch test
                    
                    case 0
                        
                        [key, rt] = csfMRI_getResponseSerial(serialOne, start, durations(iEvent,nRun));
                        
                    case 1
                            
                        [key, rt] = csfMRI_getResponse(durations(iEvent,nRun));
                        %WaitSecs(10);
                        
                end

                
            % Store reponse/RT
                
                data.responses = [data.responses; events(iEvent,nRun), key, rt, start - triggerTime, GetSecs - start];
                                
        end
        
        % Last stimulus is fixation
		
			% We do this because no trigger is provided at the end of the last TR
			% It is almost exactly the same as the above, only get_response_lumina is different
			% No response recording is made since I have the last TR be rest
				
			textRect   = Screen('TextBounds', screenPointer, '+');
        	centerRect = CenterRect(textRect, screenRect);
			Screen('DrawText', screenPointer, '+', centerRect(1), centerRect(2), 255);
			Screen('Flip', screenPointer);
            
            WaitSecs(3);
            
			disp(' '); disp(' '); disp('/// Presentation Complete ///');
		
		
		% Finish up and save the response data
		
			% Make a new folder, move into the new folder, and save the 'data' and 'stimuli' variables

			dos(['mkdir ' subID]);
			cd(subID);
			save([subID '-run' num2str(nRun)], 'data', 'stimuli');

			cd('..');
			
			% Display for the subject that the run is complete
			textRect = Screen('TextBounds', screenPointer, 'Run Complete');
			centerRect = CenterRect(textRect, screenRect);
			Screen('DrawText', screenPointer, 'Run Complete', centerRect(1), centerRect(2), 255);
			Screen('Flip', screenPointer);

			% Wait a few seconds for the subject to see the text
			WaitSecs(3);
			
			% Now, close the serial port and shut down the current screen session.
            if (test == 0)
                fclose(serialOne);
            end

			Screen('CloseAll');
			return

	
	
% -------------------------------------------------------------------------   
    
end