function [events, onsets, durations, stimuli] = csfMRI_setDesign

% Reseed the random number generator

    reset(RandStream.getGlobalStream, sum(100*clock));
    

% Load master design file and stimulus IDs, get path info

    load('./experiment.scripts/csfMRI_master.mat');
    load('./experiment.scripts/csfMRI_stimuli.mat');
    
    events    = master.events;
    onsets    = master.onsets;
    durations = master.durations;
    
    compID    = stimuli.comp;
    compPath  = cell(length(compID),1);
    %compTxt   = cell(length(compID),1);
    for nStim = 1:length(compID)
        compPath{nStim} = ['./materials.final/code_comprehension/pack1/1-' num2str(compID(nStim)) 'new.png'];
        %compTxt{nStim}  = ['./materials.final/code_comprehension/pack1/1-' num2str(compID(nStim)) '.txt'];
    end
    
    reviewID   = stimuli.review;
    reviewPath = cell(length(reviewID),1);
    %reviewTxt  = cell(length(reviewID),1);
    for nStim  = 1:length(reviewID)
        reviewPath{nStim} = ['./materials.final/code_review/new/final/' num2str(reviewID(nStim)) '.png'];
        %reviewTxt{nStim}  = ['./materials.final/code_review/final/' num2str(reviewID(nStim)) '.txt'];
    end
    
    satID     = stimuli.sat;
    bugID     = stimuli.writing;
    satPath   = cell(length(satID),1);
    bugPath   = cell(length(bugID),1);
    for nStim = 1:length(satID)
        satPath{nStim} = ['./materials.final/prose_review/sat/sat_' num2str(satID(nStim)) '.PNG'];
    end
    for nStim = 1:length(bugID)
        bugPath{nStim} = ['./materials.final/prose_review/bugs_in_writing/bugs_' num2str(bugID(nStim)) '.PNG'];
    end
    prosePath = [satPath; bugPath];
    
    clear master stimuli
    
    
% Randomize stimulus order, determine which to use for each run
    
    compIDs    = randperm(length(compPath));
    reviewIDs  = randperm(length(reviewPath));
    randComp   = compPath(compIDs);
    %randTxtC   = compTxt(compIDs);
    randReview = reviewPath(reviewIDs);
    %randTxtR   = reviewTxt(reviewIDs);
    randProse  = prosePath(randperm(length(prosePath)));
    
    randComp   = randComp(1:15);
    %randTxtC   = randTxtC(1:15);
    randReview = randReview(1:15);
    %randTxtR   = randTxtR(1:15);
    randProse  = randProse(1:15);
    
    randComp   = reshape(randComp, [3, 5]);
    %randTxtC   = reshape(randTxtC, [3, 5]);
    randReview = reshape(randReview, [3, 5]);
    %randTxtR   = reshape(randTxtR, [3, 5]);
    randProse  = reshape(randProse, [3, 5]);
    
 
% Specify full design with actual stimuli

    block1   = [4, 6, 8];
    block2   = [12, 14, 16];
    block3   = [20, 22, 24];
    instruct = [2, 10, 18];
    
    for run = 1:size(events,2)
        task = [1 2 3];
        task = task(randperm(length(task)));
        events(block1,run) = task(1);
        events(block2,run) = task(2);
        events(block3,run) = task(3);
        events(instruct,run) = events(instruct,run) .* task';
    end
    
    stimuli.ID     = cell(size(events));
    stimuli.actual = cell(size(events));
    %stimuli.txt    = cell(6,5);
    
    for run = 1:size(events,2)
        
        compCounter   = 1;
        reviewCounter = 1;
        proseCounter  = 1;
        %txtCounter    = 1;
        
        for trial = 1:size(events,1)
            
            tt = events(trial,run);
            
            switch tt
                
                case 0
                    
                    stimuli.ID(trial,run)     = cellstr('Fixation');
                    stimuli.actual(trial,run) = cellstr('+');
                    
                case 1
                    
                    img                          = imread(randComp{compCounter,run});
                    stimuli.ID(trial,run)        = cellstr(randComp{compCounter,run});
                    stimuli.actual{trial,run}    = img;
                    %stimuli.txt{txtCounter,run}  = fileread(randTxtC{compCounter,run});
                    compCounter                  = compCounter + 1;
                    %txtCounter                   = txtCounter + 1;
                    
                case 2
                    
                    img                          = imread(randReview{reviewCounter,run});
                    stimuli.ID(trial,run)        = cellstr(randReview{reviewCounter,run});
                    stimuli.actual{trial,run}    = img;
                    %stimuli.txt{txtCounter,run}  = fileread(randTxtR{reviewCounter,run});
                    reviewCounter                = reviewCounter + 1;
                    %txtCounter                   = txtCounter + 1;       
                    
                case 3
                    
                    img                       = imread(randProse{proseCounter,run});
                    stimuli.ID(trial,run)     = cellstr(randProse{proseCounter,run});
                    stimuli.actual{trial,run} = img;
                    proseCounter              = proseCounter + 1;
                    
                case -1
                    
                    stimuli.ID(trial,run)     = cellstr('CompInstruct');
                    stimuli.actual(trial,run) = cellstr('CODE\n\nCOMPREHENSION');
                    
                case -2
                    
                    stimuli.ID(trial,run)     = cellstr('ReviewInstruct');
                    stimuli.actual(trial,run) = cellstr('CODE\n\nREVIEW');
                    
                case -3
                    
                    stimuli.ID(trial,run)     = cellstr('ProseInstruct');
                    stimuli.actual(trial,run) = cellstr('ENGLISH\n\nPROSE');
                    
            end
            
        end
        
    end
        
    end
    